==> aws-cdk-lib-2.0.0-rc.20-sources.jar: software/amazon/awscdk/services/config/AccessKeysRotatedProps.java <==
package software.amazon.awscdk.services.config;

/**
 * (experimental) Construction properties for a AccessKeysRotated.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-09-01T10:26:16.397Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_config.AccessKeysRotatedProps")
@software.amazon.jsii.Jsii.Proxy(AccessKeysRotatedProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface AccessKeysRotatedProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.config.RuleProps {

    /**
     * (experimental) The maximum number of days within which the access keys must be rotated.
     * <p>
     * Default: Duration.days(90)
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.Duration getMaxAge() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AccessKeysRotatedProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AccessKeysRotatedProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<AccessKeysRotatedProps> {
        private software.amazon.awscdk.Duration maxAge;
        private java.lang.String configRuleName;
        private java.lang.String description;
        private java.util.Map<java.lang.String, java.lang.Object> inputParameters;
        private software.amazon.awscdk.services.config.MaximumExecutionFrequency maximumExecutionFrequency;
        private software.amazon.awscdk.services.config.RuleScope ruleScope;

        /**
         * Sets the value of {@link AccessKeysRotatedProps#getMaxAge}
         * @param maxAge The maximum number of days within which the access keys must be rotated.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder maxAge(software.amazon.awscdk.Duration maxAge) {
            this.maxAge = maxAge;
            return this;
        }

        /**
         * Sets the value of {@link AccessKeysRotatedProps#getConfigRuleName}
         * @param configRuleName A name for the AWS Config rule.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder configRuleName(java.lang.String configRuleName) {
            this.configRuleName = configRuleName;
            return this;
        }

        /**
         * Sets the value of {@link AccessKeysRotatedProps#getDescription}
         * @param description A description about this AWS Config rule.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder description(java.lang.String description) {
            this.description = description;
            return this;
        }

        /**
         * Sets the value of {@link AccessKeysRotatedProps#getInputParameters}
         * @param inputParameters Input parameter values that are passed to the AWS Config rule.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder inputParameters(java.util.Map<java.lang.String, ? extends java.lang.Object> inputParameters) {
            this.inputParameters = (java.util.Map<java.lang.String, java.lang.Object>)inputParameters;
            return this;
        }

        /**
         * Sets the value of {@link AccessKeysRotatedProps#getMaximumExecutionFrequency}
         * @param maximumExecutionFrequency The maximum frequency at which the AWS Config rule runs evaluations.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder maximumExecutionFrequency(software.amazon.awscdk.services.config.MaximumExecutionFrequency maximumExecutionFrequency) {
            this.maximumExecutionFrequency = maximumExecutionFrequency;
            return this;
        }

        /**
         * Sets the value of {@link AccessKeysRotatedProps#getRuleScope}
         * @param ruleScope Defines which resources trigger an evaluation for an AWS Config rule.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder ruleScope(software.amazon.awscdk.services.config.RuleScope ruleScope) {
            this.ruleScope = ruleScope;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AccessKeysRotatedProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public AccessKeysRotatedProps build() {
            return new Jsii$Proxy(maxAge, configRuleName, description, inputParameters, maximumExecutionFrequency, ruleScope);
        }
    }

    /**
     * An implementation for {@link AccessKeysRotatedProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AccessKeysRotatedProps {
        private final software.amazon.awscdk.Duration maxAge;
        private final java.lang.String configRuleName;
        private final java.lang.String description;
        private final java.util.Map<java.lang.String, java.lang.Object> inputParameters;
        private final software.amazon.awscdk.services.config.MaximumExecutionFrequency maximumExecutionFrequency;
        private final software.amazon.awscdk.services.config.RuleScope ruleScope;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.maxAge = software.amazon.jsii.Kernel.get(this, "maxAge", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.Duration.class));
            this.configRuleName = software.amazon.jsii.Kernel.get(this, "configRuleName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.description = software.amazon.jsii.Kernel.get(this, "description", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.inputParameters = software.amazon.jsii.Kernel.get(this, "inputParameters", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)));
            this.maximumExecutionFrequency = software.amazon.jsii.Kernel.get(this, "maximumExecutionFrequency", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.config.MaximumExecutionFrequency.class));
            this.ruleScope = software.amazon.jsii.Kernel.get(this, "ruleScope", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.config.RuleScope.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final software.amazon.awscdk.Duration maxAge, final java.lang.String configRuleName, final java.lang.String description, final java.util.Map<java.lang.String, ? extends java.lang.Object> inputParameters, final software.amazon.awscdk.services.config.MaximumExecutionFrequency maximumExecutionFrequency, final software.amazon.awscdk.services.config.RuleScope ruleScope) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.maxAge = maxAge;
            this.configRuleName = configRuleName;
            this.description = description;
            this.inputParameters = (java.util.Map<java.lang.String, java.lang.Object>)inputParameters;
            this.maximumExecutionFrequency = maximumExecutionFrequency;
            this.ruleScope = ruleScope;
        }

        @Override
        public final software.amazon.awscdk.Duration getMaxAge() {
            return this.maxAge;
        }

        @Override
        public final java.lang.String getConfigRuleName() {
            return this.configRuleName;
        }

        @Override
        public final java.lang.String getDescription() {
            return this.description;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.Object> getInputParameters() {
            return this.inputParameters;
        }

        @Override
        public final software.amazon.awscdk.services.config.MaximumExecutionFrequency getMaximumExecutionFrequency() {
            return this.maximumExecutionFrequency;
        }

        @Override
        public final software.amazon.awscdk.services.config.RuleScope getRuleScope() {
            return this.ruleScope;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getMaxAge() != null) {
                data.set("maxAge", om.valueToTree(this.getMaxAge()));
            }
            if (this.getConfigRuleName() != null) {
                data.set("configRuleName", om.valueToTree(this.getConfigRuleName()));
            }
            if (this.getDescription() != null) {
                data.set("description", om.valueToTree(this.getDescription()));
            }
            if (this.getInputParameters() != null) {
                data.set("inputParameters", om.valueToTree(this.getInputParameters()));
            }
            if (this.getMaximumExecutionFrequency() != null) {
                data.set("maximumExecutionFrequency", om.valueToTree(this.getMaximumExecutionFrequency()));
            }
            if (this.getRuleScope() != null) {
                data.set("ruleScope", om.valueToTree(this.getRuleScope()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_config.AccessKeysRotatedProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AccessKeysRotatedProps.Jsii$Proxy that = (AccessKeysRotatedProps.Jsii$Proxy) o;

            if (this.maxAge != null ? !this.maxAge.equals(that.maxAge) : that.maxAge != null) return false;
            if (this.configRuleName != null ? !this.configRuleName.equals(that.configRuleName) : that.configRuleName != null) return false;
            if (this.description != null ? !this.description.equals(that.description) : that.description != null) return false;
            if (this.inputParameters != null ? !this.inputParameters.equals(that.inputParameters) : that.inputParameters != null) return false;
            if (this.maximumExecutionFrequency != null ? !this.maximumExecutionFrequency.equals(that.maximumExecutionFrequency) : that.maximumExecutionFrequency != null) return false;
            return this.ruleScope != null ? this.ruleScope.equals(that.ruleScope) : that.ruleScope == null;
        }

        @Override
        public final int hashCode() {
            int result = this.maxAge != null ? this.maxAge.hashCode() : 0;
            result = 31 * result + (this.configRuleName != null ? this.configRuleName.hashCode() : 0);
            result = 31 * result + (this.description != null ? this.description.hashCode() : 0);
            result = 31 * result + (this.inputParameters != null ? this.inputParameters.hashCode() : 0);
            result = 31 * result + (this.maximumExecutionFrequency != null ? this.maximumExecutionFrequency.hashCode() : 0);
            result = 31 * result + (this.ruleScope != null ? this.ruleScope.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/config/AccessKeysRotatedProps.java <==
package software.amazon.awscdk.services.config;

/**
 * Construction properties for a AccessKeysRotated.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.*;
 * import software.amazon.awscdk.services.config.*;
 * Object inputParameters;
 * RuleScope ruleScope;
 * AccessKeysRotatedProps accessKeysRotatedProps = AccessKeysRotatedProps.builder()
 *         .configRuleName("configRuleName")
 *         .description("description")
 *         .inputParameters(Map.of(
 *                 "inputParametersKey", inputParameters))
 *         .maxAge(Duration.minutes(30))
 *         .maximumExecutionFrequency(MaximumExecutionFrequency.ONE_HOUR)
 *         .ruleScope(ruleScope)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:08.601Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_config.AccessKeysRotatedProps")
@software.amazon.jsii.Jsii.Proxy(AccessKeysRotatedProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface AccessKeysRotatedProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.config.RuleProps {

    /**
     * The maximum number of days within which the access keys must be rotated.
     * <p>
     * Default: Duration.days(90)
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.Duration getMaxAge() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AccessKeysRotatedProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AccessKeysRotatedProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<AccessKeysRotatedProps> {
        software.amazon.awscdk.Duration maxAge;
        java.lang.String configRuleName;
        java.lang.String description;
        java.util.Map<java.lang.String, java.lang.Object> inputParameters;
        software.amazon.awscdk.services.config.MaximumExecutionFrequency maximumExecutionFrequency;
        software.amazon.awscdk.services.config.RuleScope ruleScope;

        /**
         * Sets the value of {@link AccessKeysRotatedProps#getMaxAge}
         * @param maxAge The maximum number of days within which the access keys must be rotated.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder maxAge(software.amazon.awscdk.Duration maxAge) {
            this.maxAge = maxAge;
            return this;
        }

        /**
         * Sets the value of {@link AccessKeysRotatedProps#getConfigRuleName}
         * @param configRuleName A name for the AWS Config rule.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder configRuleName(java.lang.String configRuleName) {
            this.configRuleName = configRuleName;
            return this;
        }

        /**
         * Sets the value of {@link AccessKeysRotatedProps#getDescription}
         * @param description A description about this AWS Config rule.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder description(java.lang.String description) {
            this.description = description;
            return this;
        }

        /**
         * Sets the value of {@link AccessKeysRotatedProps#getInputParameters}
         * @param inputParameters Input parameter values that are passed to the AWS Config rule.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder inputParameters(java.util.Map<java.lang.String, ? extends java.lang.Object> inputParameters) {
            this.inputParameters = (java.util.Map<java.lang.String, java.lang.Object>)inputParameters;
            return this;
        }

        /**
         * Sets the value of {@link AccessKeysRotatedProps#getMaximumExecutionFrequency}
         * @param maximumExecutionFrequency The maximum frequency at which the AWS Config rule runs evaluations.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder maximumExecutionFrequency(software.amazon.awscdk.services.config.MaximumExecutionFrequency maximumExecutionFrequency) {
            this.maximumExecutionFrequency = maximumExecutionFrequency;
            return this;
        }

        /**
         * Sets the value of {@link AccessKeysRotatedProps#getRuleScope}
         * @param ruleScope Defines which resources trigger an evaluation for an AWS Config rule.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ruleScope(software.amazon.awscdk.services.config.RuleScope ruleScope) {
            this.ruleScope = ruleScope;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AccessKeysRotatedProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public AccessKeysRotatedProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link AccessKeysRotatedProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AccessKeysRotatedProps {
        private final software.amazon.awscdk.Duration maxAge;
        private final java.lang.String configRuleName;
        private final java.lang.String description;
        private final java.util.Map<java.lang.String, java.lang.Object> inputParameters;
        private final software.amazon.awscdk.services.config.MaximumExecutionFrequency maximumExecutionFrequency;
        private final software.amazon.awscdk.services.config.RuleScope ruleScope;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.maxAge = software.amazon.jsii.Kernel.get(this, "maxAge", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.Duration.class));
            this.configRuleName = software.amazon.jsii.Kernel.get(this, "configRuleName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.description = software.amazon.jsii.Kernel.get(this, "description", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.inputParameters = software.amazon.jsii.Kernel.get(this, "inputParameters", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)));
            this.maximumExecutionFrequency = software.amazon.jsii.Kernel.get(this, "maximumExecutionFrequency", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.config.MaximumExecutionFrequency.class));
            this.ruleScope = software.amazon.jsii.Kernel.get(this, "ruleScope", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.config.RuleScope.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.maxAge = builder.maxAge;
            this.configRuleName = builder.configRuleName;
            this.description = builder.description;
            this.inputParameters = (java.util.Map<java.lang.String, java.lang.Object>)builder.inputParameters;
            this.maximumExecutionFrequency = builder.maximumExecutionFrequency;
            this.ruleScope = builder.ruleScope;
        }

        @Override
        public final software.amazon.awscdk.Duration getMaxAge() {
            return this.maxAge;
        }

        @Override
        public final java.lang.String getConfigRuleName() {
            return this.configRuleName;
        }

        @Override
        public final java.lang.String getDescription() {
            return this.description;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.Object> getInputParameters() {
            return this.inputParameters;
        }

        @Override
        public final software.amazon.awscdk.services.config.MaximumExecutionFrequency getMaximumExecutionFrequency() {
            return this.maximumExecutionFrequency;
        }

        @Override
        public final software.amazon.awscdk.services.config.RuleScope getRuleScope() {
            return this.ruleScope;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getMaxAge() != null) {
                data.set("maxAge", om.valueToTree(this.getMaxAge()));
            }
            if (this.getConfigRuleName() != null) {
                data.set("configRuleName", om.valueToTree(this.getConfigRuleName()));
            }
            if (this.getDescription() != null) {
                data.set("description", om.valueToTree(this.getDescription()));
            }
            if (this.getInputParameters() != null) {
                data.set("inputParameters", om.valueToTree(this.getInputParameters()));
            }
            if (this.getMaximumExecutionFrequency() != null) {
                data.set("maximumExecutionFrequency", om.valueToTree(this.getMaximumExecutionFrequency()));
            }
            if (this.getRuleScope() != null) {
                data.set("ruleScope", om.valueToTree(this.getRuleScope()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_config.AccessKeysRotatedProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AccessKeysRotatedProps.Jsii$Proxy that = (AccessKeysRotatedProps.Jsii$Proxy) o;

            if (this.maxAge != null ? !this.maxAge.equals(that.maxAge) : that.maxAge != null) return false;
            if (this.configRuleName != null ? !this.configRuleName.equals(that.configRuleName) : that.configRuleName != null) return false;
            if (this.description != null ? !this.description.equals(that.description) : that.description != null) return false;
            if (this.inputParameters != null ? !this.inputParameters.equals(that.inputParameters) : that.inputParameters != null) return false;
            if (this.maximumExecutionFrequency != null ? !this.maximumExecutionFrequency.equals(that.maximumExecutionFrequency) : that.maximumExecutionFrequency != null) return false;
            return this.ruleScope != null ? this.ruleScope.equals(that.ruleScope) : that.ruleScope == null;
        }

        @Override
        public final int hashCode() {
            int result = this.maxAge != null ? this.maxAge.hashCode() : 0;
            result = 31 * result + (this.configRuleName != null ? this.configRuleName.hashCode() : 0);
            result = 31 * result + (this.description != null ? this.description.hashCode() : 0);
            result = 31 * result + (this.inputParameters != null ? this.inputParameters.hashCode() : 0);
            result = 31 * result + (this.maximumExecutionFrequency != null ? this.maximumExecutionFrequency.hashCode() : 0);
            result = 31 * result + (this.ruleScope != null ? this.ruleScope.hashCode() : 0);
            return result;
        }
    }
}
